@@ -1,9 +1,9 @@
 __author__ = """Francisco Fernandez"""
 __email__ = "fernandezfrancisco2195@gmail.com"
-__version__ = "0.1.0" 
+__version__ = "0.2.0" 
 
 
-from exma.atoms import positions
+from exma.atoms import positions, nanoparticle, replicate
 from exma.boundary.condition import periodic, minimum_image
 from exma.cluster.clusterization import dbscan
 from exma.cn.coordination_number import monoatomic, diatomic
@@ -11,5 +11,6 @@ from exma.en.effective_neighbors import hoppe
 from exma.msd import monoatomic, diatomic
 from exma.rdf.gofr import monoatomic, diatomic
 from exma.reader import xyz, lammpstrj
+from exma.sro import amorphous
 from exma.statistics import block_average
 from exma.writer import xyz, lammpstrj
